@@ -25,12 +25,12 @@ impl Pid {
     }
 }
 
-#[cfg(target_os = "linux")]
+#[cfg(any(target_os = "linux", target_os = "android"))]
 impl Column for Pid {
     fn add(&mut self, proc: &ProcessInfo) {
         let raw_content = proc.pid;
         let fmt_content = match proc.curr_proc {
-            crate::process::ProcessTask::Process(_) => format!("{}", raw_content),
+            crate::process::ProcessTask::Process { .. } => format!("{}", raw_content),
             _ => format!("[{}]", raw_content),
         };
 
@@ -41,7 +41,7 @@ impl Column for Pid {
     column_default!(i32);
 }
 
-#[cfg(not(target_os = "linux"))]
+#[cfg(not(any(target_os = "linux", target_os = "android")))]
 impl Column for Pid {
     fn add(&mut self, proc: &ProcessInfo) {
         let raw_content = proc.pid;
