@@ -4,7 +4,10 @@ use crate::config::*;
 use crate::process::collect_proc;
 use crate::style::{apply_color, apply_style, color_to_column_style};
 use crate::term_info::TermInfo;
-use crate::util::{classify, find_column_kind, find_exact, find_partial, truncate, KeywordClass};
+use crate::util::{
+    classify, find_column_kind, find_exact, find_partial, truncate, ArgColorMode, ArgPagerMode,
+    KeywordClass,
+};
 use crate::Opt;
 use anyhow::{bail, Error};
 #[cfg(not(target_os = "windows"))]
@@ -31,34 +34,45 @@ impl View {
     pub fn new(opt: &Opt, config: &Config, clear_by_line: bool) -> Result<Self, Error> {
         let mut slot_idx = 0;
         let mut columns = Vec::new();
-        if opt.tree {
-            let kind = ConfigColumnKind::Tree;
-            let column = gen_column(
-                &kind,
-                None,
-                &config.docker.path,
-                &config.display.separator,
-                config.display.abbr_sid,
-                &config.display.tree_symbols,
-            );
-            if column.available() {
-                columns.push(ColumnInfo {
-                    column,
-                    kind,
-                    style: color_to_column_style(&config.style.tree),
-                    nonnumeric_search: false,
-                    numeric_search: false,
-                    align: ConfigColumnAlign::Left,
-                    max_width: None,
-                    min_width: None,
-                    visible: true,
-                });
-            }
-        }
-
         let mut only_kind_found = false;
 
-        for c in &config.columns {
+        // Override style of TreeSlot
+        let tree_slot = ConfigColumn {
+            kind: ConfigColumnKind::TreeSlot,
+            style: color_to_column_style(&config.style.tree),
+            numeric_search: false,
+            nonnumeric_search: false,
+            align: ConfigColumnAlign::Left,
+            max_width: None,
+            min_width: None,
+            header: None,
+        };
+
+        // Add default TreeSlot if there is not TreeSlot in config
+        let config_columns = if config
+            .columns
+            .iter()
+            .all(|x| x.kind != ConfigColumnKind::TreeSlot)
+            && opt.tree
+        {
+            let mut ret = vec![tree_slot];
+            ret.append(&mut config.columns.clone());
+            ret
+        } else {
+            config
+                .columns
+                .iter()
+                .map(|x| {
+                    if x.kind == ConfigColumnKind::TreeSlot {
+                        tree_slot.clone()
+                    } else {
+                        x.clone()
+                    }
+                })
+                .collect()
+        };
+
+        for c in &config_columns {
             let kinds = match &c.kind {
                 ConfigColumnKind::Slot => {
                     let kinds = if let Some(insert) = opt.insert.get(slot_idx) {
@@ -79,13 +93,20 @@ impl View {
                     }
                     kinds
                 }
+                ConfigColumnKind::TreeSlot => {
+                    if opt.tree {
+                        vec![ConfigColumnKind::Tree]
+                    } else {
+                        vec![]
+                    }
+                }
                 x => vec![x.clone()],
             };
 
             for kind in kinds {
                 let visible = if let Some(ref only) = opt.only {
                     let kind_name = KIND_LIST[&kind].0.to_lowercase();
-                    if kind_name.find(&only.to_lowercase()).is_none() {
+                    if !kind_name.contains(&only.to_lowercase()) {
                         false
                     } else {
                         only_kind_found = true;
@@ -140,7 +161,7 @@ impl View {
         let proc = collect_proc(Duration::from_millis(opt.interval), show_thread);
         for c in columns.iter_mut() {
             for p in &proc {
-                c.column.add(&p);
+                c.column.add(p);
             }
         }
 
@@ -228,7 +249,7 @@ impl View {
                     &keyword_nonnumeric,
                     cols_numeric.as_slice(),
                     cols_nonnumeric.as_slice(),
-                    &config,
+                    config,
                     &logic,
                 )
             };
@@ -304,7 +325,7 @@ impl View {
             };
             c.column.apply_visible(&self.visible_pids);
             let min_width = min_widths.get(&i).map(|x| Some(*x)).unwrap_or(c.min_width);
-            c.column.reset_width(order, &config, c.max_width, min_width);
+            c.column.reset_width(order, config, c.max_width, min_width);
             for pid in &self.visible_pids {
                 c.column.update_width(*pid, c.max_width);
             }
@@ -339,19 +360,18 @@ impl View {
         } else {
             match (opt.watch_mode, opt.pager.as_ref(), &config.pager.mode) {
                 (true, _, _) => false,
-                (false, Some(x), _) if x == "auto" => {
+                (false, Some(ArgPagerMode::Auto), _) => {
                     self.term_info.height < pager_threshold_height
                         || self.term_info.width < pager_threshold_width
                 }
-                (false, Some(x), _) if x == "always" => true,
-                (false, Some(x), _) if x == "disable" => false,
+                (false, Some(ArgPagerMode::Always), _) => true,
+                (false, Some(ArgPagerMode::Disable), _) => false,
                 (false, None, ConfigPagerMode::Auto) => {
                     self.term_info.height < pager_threshold_height
                         || self.term_info.width < pager_threshold_width
                 }
                 (false, None, ConfigPagerMode::Always) => true,
                 (false, None, ConfigPagerMode::Disable) => false,
-                _ => false,
             }
         };
 
@@ -364,13 +384,13 @@ impl View {
         }
 
         match (opt.color.as_ref(), &config.display.color_mode) {
-            (Some(x), _) if x == "auto" => {
+            (Some(ArgColorMode::Auto), _) => {
                 if use_pager && use_terminal {
                     console::set_colors_enabled(true);
                 }
             }
-            (Some(x), _) if x == "always" => console::set_colors_enabled(true),
-            (Some(x), _) if x == "disable" => console::set_colors_enabled(false),
+            (Some(ArgColorMode::Always), _) => console::set_colors_enabled(true),
+            (Some(ArgColorMode::Disable), _) => console::set_colors_enabled(false),
             (None, ConfigColorMode::Auto) => {
                 if use_pager && use_terminal {
                     console::set_colors_enabled(true);
@@ -378,23 +398,22 @@ impl View {
             }
             (None, ConfigColorMode::Always) => console::set_colors_enabled(true),
             (None, ConfigColorMode::Disable) => console::set_colors_enabled(false),
-            _ => (),
         }
 
         if use_pager {
-            View::pager(&config);
+            View::pager(config);
         }
 
         if !opt.no_header {
             // Ignore display_* error
             //   `Broken pipe` may occur at pager mode. It can be ignored safely.
-            let _ = self.display_header(&config, theme);
-            let _ = self.display_unit(&config, theme);
+            let _ = self.display_header(config, theme);
+            let _ = self.display_unit(config, theme);
         }
 
         for pid in &self.visible_pids {
             let auxiliary = self.auxiliary_pids.contains(pid);
-            let _ = self.display_content(&config, *pid, theme, auxiliary);
+            let _ = self.display_content(config, *pid, theme, auxiliary);
         }
 
         Ok(())
@@ -485,7 +504,7 @@ impl View {
                 let mut order = config.sort.order.clone();
                 for (i, c) in cols.iter().enumerate() {
                     let (kind, _) = KIND_LIST[&c.kind];
-                    if kind.to_lowercase().find(&sort.to_lowercase()).is_some() {
+                    if kind.to_lowercase().contains(&sort.to_lowercase()) {
                         idx = i;
                         order = if opt.sorta.is_some() {
                             ConfigSortOrder::Ascending
@@ -501,7 +520,10 @@ impl View {
         };
 
         if opt.tree {
-            sort_idx = 0;
+            sort_idx = cols
+                .iter()
+                .position(|x| x.kind == ConfigColumnKind::Tree)
+                .unwrap();
         }
 
         SortInfo {
@@ -520,14 +542,36 @@ impl View {
         logic: &ConfigSearchLogic,
     ) -> bool {
         let ret_nonnumeric = match config.search.nonnumeric_search {
-            ConfigSearchKind::Partial => {
-                find_partial(cols_nonnumeric, pid, keyword_nonnumeric, logic)
-            }
-            ConfigSearchKind::Exact => find_exact(cols_nonnumeric, pid, keyword_nonnumeric, logic),
+            ConfigSearchKind::Partial => find_partial(
+                cols_nonnumeric,
+                pid,
+                keyword_nonnumeric,
+                logic,
+                &config.search.case,
+            ),
+            ConfigSearchKind::Exact => find_exact(
+                cols_nonnumeric,
+                pid,
+                keyword_nonnumeric,
+                logic,
+                &config.search.case,
+            ),
         };
         let ret_numeric = match config.search.numeric_search {
-            ConfigSearchKind::Partial => find_partial(cols_numeric, pid, keyword_numeric, logic),
-            ConfigSearchKind::Exact => find_exact(cols_numeric, pid, keyword_numeric, logic),
+            ConfigSearchKind::Partial => find_partial(
+                cols_numeric,
+                pid,
+                keyword_numeric,
+                logic,
+                &config.search.case,
+            ),
+            ConfigSearchKind::Exact => find_exact(
+                cols_numeric,
+                pid,
+                keyword_numeric,
+                logic,
+                &config.search.case,
+            ),
         };
         match logic {
             ConfigSearchLogic::And => ret_nonnumeric & ret_numeric,
@@ -551,8 +595,8 @@ impl View {
     #[cfg(any(target_os = "linux", target_os = "android"))]
     fn pager(config: &Config) {
         if let Some(ref pager) = config.pager.command {
-            Pager::with_pager(&pager)
-                // workaround for default less charset is "acsii" on some environments (ex. Ubuntu)
+            Pager::with_pager(pager)
+                // workaround for default less charset is "ascii" on some environments (ex. Ubuntu)
                 .pager_envs(&["LESSCHARSET=utf-8"])
                 .setup();
         } else if which::which("less").is_ok() {
